@@ -16,8 +16,8 @@ JS_LOOKUP = {
     "is_installed": """
         return window.seleniumtestabilityready !== undefined && window.seleniumtestabilityready == true
     """,
-    "useragent": """
-        return navigator.userAgent;
+    "navigator": """
+        return navigator[arguments[0]]
     """,
     "dragdrop": """
         window.simulateDragDrop(arguments[0], arguments[1]);
@@ -43,4 +43,25 @@ JS_LOOKUP = {
     "set_element_attribute": """
         arguments[0].setAttribute(arguments[1], arguments[2])
     """,
+    "get_window_location": """
+        return window.location[arguments[0]]
+    """,
+    "storage_getitem": """
+        return window[arguments[0]].getItem(arguments[1])
+    """,
+    "storage_setitem": """
+        window[arguments[0]].setItem(arguments[1], arguments[2])
+    """,
+    "storage_length": """
+        return window[arguments[0]].length
+    """,
+    "storage_removeitem": """
+        return window[arguments[0]].removeItem(arguments[1])
+    """,
+    "storage_clear": """
+        return window[arguments[0]].clear()
+    """,
+    "storage_keys": """
+        return Object.keys(window[arguments[0]])
+    """,
 }
