@@ -17,7 +17,8 @@ log_name = location / "SeleniumTestability.log"
 log_handler = logging.FileHandler(log_name)
 formatter = logging.Formatter("%(asctime)s - %(name)s - %(levelname)s - %(message)s")
 log_handler.setFormatter(formatter)
-LEVELS = {"FAIL": logging.DEBUG, "WARN": logging.warn, "INFO": logging.INFO, "DEBUG": logging.debug, "TRACE": logging.DEBUG}
+LEVELS = {"FAIL": logging.DEBUG, "WARN": logging.WARN, "INFO": logging.INFO,
+          "DEBUG": logging.DEBUG, "TRACE": logging.DEBUG}
 
 
 @lru_cache(maxsize=1)
@@ -25,7 +26,7 @@ def get_logger(name: str) -> Any:
     lgr = logging.getLogger(name)
     lgr.addHandler(log_handler)
     set_to = LEVELS[robot_log_level]
-    lgr.setLevel(set_to)  # type: ignore
+    lgr.setLevel(set_to)
     lgr.debug(" **** New Session Created for {}  **** ".format(name))
     return lgr
 
