@@ -1,9 +1,15 @@
 # -*- coding: utf-8 -*-
-from typing import Union, Optional, List
+from typing import Union, Optional, List, Dict
 from selenium.webdriver.support.event_firing_webdriver import EventFiringWebElement, EventFiringWebDriver
 from selenium.webdriver import Firefox
 from selenium.webdriver.remote.webelement import WebElement
-from psutil import Process
+
+try:
+    # Only required during development.
+    from psutil import Process
+    ProcessType = Union[Process, int]
+except ModuleNotFoundError:
+    pass
 
 WebElementType = Union[WebElement, EventFiringWebElement]
 LocatorType = Union[WebElementType, EventFiringWebElement, str]
@@ -11,8 +17,9 @@ OptionalBoolType = Optional[bool]
 OptionalStrType = Optional[str]
 OptionalDictType = Optional[str]
 BrowserLogsType = List[str]
-ProcessType = Union[Process, int]
+StringArray = List[str]
 FirefoxWebDriverType = Union[Firefox, EventFiringWebDriver]
+StorageType = Union[Dict, bool, str, int, float]
 
 
 def is_firefox(webdriver: FirefoxWebDriverType) -> bool:
